@@ -24,6 +24,9 @@ class PIMCOMMON_EXPORT ConfigurePluginsListWidget : public QWidget
 {
     Q_OBJECT
 public:
+    enum PluginItemData {
+        Description = Qt::UserRole + 1,
+    };
     explicit ConfigurePluginsListWidget(QWidget *parent = nullptr);
     ~ConfigurePluginsListWidget() override;
 
@@ -34,14 +37,9 @@ public:
     virtual void initialize();
     void initializeDone();
 Q_SIGNALS:
-    void descriptionChanged(const QString &description);
     void changed();
     void configureClicked(const QString &configureGroupName, const QString &identifier);
 
-private:
-    PIMCOMMON_NO_EXPORT void slotItemSelectionChanged();
-    PIMCOMMON_NO_EXPORT void slotItemChanged(QTreeWidgetItem *item, int column);
-
 protected:
     class PluginItem : public QTreeWidgetItem
     {
@@ -52,7 +50,6 @@ protected:
         }
 
         QString mIdentifier;
-        QString mDescription;
         bool mEnableByDefault = false;
         bool mHasConfigureSupport = false;
         bool mEnableFromUserSettings = false;
@@ -71,8 +68,9 @@ protected:
     QTreeWidget *const mListWidget;
 
 private:
-    KTreeWidgetSearchLineWidget *mTreeWidgetSearchLineEdit = nullptr;
+    PIMCOMMON_NO_EXPORT void slotItemChanged(QTreeWidgetItem *item, int column);
     PIMCOMMON_NO_EXPORT void slotConfigureClicked(QAction *act);
+    KTreeWidgetSearchLineWidget *mTreeWidgetSearchLineEdit = nullptr;
     bool mInitializeDone = false;
 };
 }
