@@ -8,8 +8,6 @@
 
 #include "pimcommon_export.h"
 #include <QWidget>
-class QSplitter;
-class QTextEdit;
 class KMessageWidget;
 namespace PimCommon
 {
@@ -32,18 +30,14 @@ public:
     void doResetToDefaultsOther();
 
 Q_SIGNALS:
-    void changed();
+    void wasChanged(bool changed);
 
 private:
     PIMCOMMON_NO_EXPORT void initialize();
-    PIMCOMMON_NO_EXPORT void readConfig();
-    PIMCOMMON_NO_EXPORT void writeConfig();
     PIMCOMMON_NO_EXPORT void slotConfigChanged();
     PIMCOMMON_NO_EXPORT void initLayout(ConfigurePluginsListWidget *configurePluginListWidget = nullptr);
 
-    QSplitter *mSplitter = nullptr;
     ConfigurePluginsListWidget *mConfigureListWidget = nullptr;
-    QTextEdit *mDescription = nullptr;
     KMessageWidget *mMessageWidget = nullptr;
 };
 }
