@@ -19,7 +19,7 @@ using namespace Qt::Literals::StringLiterals;
 #include "addresseelineeditmanager.h"
 #include "addresseelineeditutil.h"
 #include "addressline/recentaddress/recentaddresses.h"
-#include <KLDAPWidgets/LdapClientSearch>
+#include <KLDAPCore/LdapClientSearch>
 
 #include <KContacts/VCardConverter>
 
@@ -562,7 +562,7 @@ QMenu *AddresseeLineEdit::createStandardContextMenu()
         return nullptr;
     }
     if (d->useCompletion()) {
-        auto showOU = new QAction(i18n("Show Organization Unit for LDAP results"), menu);
+        auto showOU = new QAction(i18nc("@action", "Show Organization Unit for LDAP results"), menu);
         showOU->setCheckable(true);
         showOU->setChecked(d->showOU());
         connect(showOU, &QAction::triggered, d, &AddresseeLineEditPrivate::slotShowOUChanged);
@@ -854,7 +854,7 @@ void AddresseeLineEdit::updateCompletionOrder()
     d->updateCompletionOrder();
 }
 
-KLDAPWidgets::LdapClientSearch *AddresseeLineEdit::ldapSearch() const
+KLDAPCore::LdapClientSearch *AddresseeLineEdit::ldapSearch() const
 {
     return d->ldapSearch();
 }
