@@ -6,9 +6,9 @@
 
 #include "addresseelineeditldap.h"
 #include "addresseelineeditmanager.h"
+#include <KLDAPCore/LdapClient>
+#include <KLDAPCore/LdapClientSearch>
 #include <KLDAPCore/LdapServer>
-#include <KLDAPWidgets/LdapClient>
-#include <KLDAPWidgets/LdapClientSearch>
 #include <KLocalizedString>
 #include <QTimer>
 #include <chrono>
@@ -30,8 +30,8 @@ void AddresseeLineEditLdap::updateLDAPWeights()
      * that they map to the LdapClient::clientNumber() */
     mLdapSearch->updateCompletionWeights();
     int clientIndex = 0;
-    const QList<KLDAPWidgets::LdapClient *> lstClients = mLdapSearch->clients();
-    for (const KLDAPWidgets::LdapClient *client : lstClients) {
+    const QList<KLDAPCore::LdapClient *> lstClients = mLdapSearch->clients();
+    for (const KLDAPCore::LdapClient *client : lstClients) {
         const int sourceIndex = mAddressLineStatic->addCompletionSource(i18n("LDAP server: %1", client->server().host()), client->completionWeight());
         mLdapClientToCompletionSourceMap.insert(clientIndex, sourceIndex);
         ++clientIndex;
@@ -53,7 +53,7 @@ bool AddresseeLineEditLdap::isLdapClientToCompletionSourceMapContains(int value)
     return mLdapClientToCompletionSourceMap.contains(value);
 }
 
-KLDAPWidgets::LdapClientSearch *AddresseeLineEditLdap::ldapSearch() const
+KLDAPCore::LdapClientSearch *AddresseeLineEditLdap::ldapSearch() const
 {
     return mLdapSearch;
 }
@@ -62,7 +62,7 @@ void AddresseeLineEditLdap::init()
 {
     if (!mLdapTimer) {
         mLdapTimer = new QTimer(this);
-        mLdapSearch = new KLDAPWidgets::LdapClientSearch(this);
+        mLdapSearch = new KLDAPCore::LdapClientSearch(this);
 
         /* The reasoning behind this filter is:
          * If it's a person, or a distlist, show it, even if it doesn't have an email address.
