@@ -13,7 +13,7 @@
 #include "pimcommonakonadi_debug.h"
 #include <KColorScheme>
 #include <KConfigGroup>
-#include <KLDAPWidgets/LdapClient>
+#include <KLDAPCore/LdapClient>
 #include <KSharedConfig>
 #include <QCoreApplication>
 #include <QNetworkInformation>
@@ -114,14 +114,15 @@ void AddresseeLineEditManager::setAddressLineEdit(AddresseeLineEdit *addressLine
 bool AddresseeLineEditManager::isOnline() const
 {
     if (QNetworkInformation::loadBackendByFeatures(QNetworkInformation::Feature::Reachability)) {
-        return QNetworkInformation::instance()->reachability() == QNetworkInformation::Reachability::Online;
+        return QNetworkInformation::instance()->reachability() == QNetworkInformation::Reachability::Online
+            && !QNetworkInformation::instance()->isBehindCaptivePortal();
     } else {
         qCWarning(PIMCOMMONAKONADI_LOG) << "Couldn't find a working backend for QNetworkInformation";
         return false;
     }
 }
 
-KLDAPWidgets::LdapClientSearch *AddresseeLineEditManager::ldapSearch() const
+KLDAPCore::LdapClientSearch *AddresseeLineEditManager::ldapSearch() const
 {
     return mAddressessLineEditLdap->ldapSearch();
 }
