@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2024 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -29,4 +29,6 @@ private Q_SLOTS:
     void shouldExcludeDuplicateEntryWithDisplayNameAddAddressWithDifferentCase();
     void shouldExcludeDuplicateEntryWithDifferentDisplayNameAddAddressWithDifferentCase();
     void shouldExcludeEmptyNameWithDisplayNameForSameAddress();
+    void shouldReturnSameListIfBlackListInterceptEmail();
+    void shouldExcludeEmails();
 };
