@@ -34,10 +34,10 @@ BlackListBalooEmailCompletionWidget::BlackListBalooEmailCompletionWidget(QWidget
     , mExcludeDomainLineEdit(new QLineEdit(this))
     , mEmailList(new BlackListBalooEmailList(this))
     , mSearchButton(new QPushButton(QIcon::fromTheme(QStringLiteral("edit-find")), i18n("Search"), this))
-    , mSelectButton(new QPushButton(i18n("&Select"), this))
-    , mUnselectButton(new QPushButton(i18n("&Unselect"), this))
-    , mShowAllBlackListedEmails(new QPushButton(i18n("Show Blacklisted Emails"), this))
-    , mMoreResult(new QLabel(i18n("<qt><a href=\"more_result\">More result...</a></qt>"), this))
+    , mSelectButton(new QPushButton(i18nc("@action:button", "&Select"), this))
+    , mUnselectButton(new QPushButton(i18nc("@action:button", "&Unselect"), this))
+    , mShowAllBlackListedEmails(new QPushButton(i18nc("@action:button", "Show Blacklisted Emails"), this))
+    , mMoreResult(new QLabel(i18nc("@label:textbox", "<qt><a href=\"more_result\">More result...</a></qt>"), this))
     , mBlackListWarning(new BlackListBalooEmailWarning(this))
     , mExcludeEmailFromRegularExpressionLineEdit(new QLineEdit(this))
 {
@@ -46,11 +46,11 @@ BlackListBalooEmailCompletionWidget::BlackListBalooEmailCompletionWidget(QWidget
     auto searchLayout = new QHBoxLayout;
     mainLayout->addLayout(searchLayout);
 
-    auto lab = new QLabel(i18n("Search email:"), this);
+    auto lab = new QLabel(i18nc("@label:textbox", "Search email:"), this);
     lab->setObjectName("search_label"_L1);
     searchLayout->addWidget(lab);
 
-    mSearchLineEdit->setPlaceholderText(i18n("Research is done from 3 characters"));
+    mSearchLineEdit->setPlaceholderText(i18nc("@info:placeholder", "Research is done from 3 characters"));
     mSearchLineEdit->setFocus();
     mSearchLineEdit->setClearButtonEnabled(true);
     KLineEditEventHandler::catchReturnKey(mSearchLineEdit);
@@ -102,7 +102,7 @@ BlackListBalooEmailCompletionWidget::BlackListBalooEmailCompletionWidget(QWidget
     mSearchInResultLineEdit = new KListWidgetSearchLine(this, mEmailList);
     mSearchInResultLineEdit->setObjectName("searchinresultlineedit"_L1);
     mSearchInResultLineEdit->setClearButtonEnabled(true);
-    mSearchInResultLineEdit->setPlaceholderText(i18n("Search in result..."));
+    mSearchInResultLineEdit->setPlaceholderText(i18nc("@info:placeholder", "Search in result..."));
     KLineEditEventHandler::catchReturnKey(mSearchInResultLineEdit);
 
     searchLineLayout->addStretch(0);
@@ -115,7 +115,7 @@ BlackListBalooEmailCompletionWidget::BlackListBalooEmailCompletionWidget(QWidget
     excludeDomainLayout->setContentsMargins({});
     mainLayout->addLayout(excludeDomainLayout);
 
-    auto excludeDomainLabel = new QLabel(i18n("Exclude domain names:"), this);
+    auto excludeDomainLabel = new QLabel(i18nc("@label:textbox", "Exclude domain names:"), this);
     excludeDomainLabel->setObjectName("domain_label"_L1);
     excludeDomainLayout->addWidget(excludeDomainLabel);
 
@@ -123,13 +123,13 @@ BlackListBalooEmailCompletionWidget::BlackListBalooEmailCompletionWidget(QWidget
     mExcludeDomainLineEdit->setObjectName("domain_lineedit"_L1);
     mExcludeDomainLineEdit->setClearButtonEnabled(true);
     KLineEditEventHandler::catchReturnKey(mExcludeDomainLineEdit);
-    mExcludeDomainLineEdit->setPlaceholderText(i18n("Separate domain with \'%1\'", QLatin1Char(',')));
+    mExcludeDomainLineEdit->setPlaceholderText(i18nc("@info:placeholder", "Separate domain with \'%1\'", QLatin1Char(',')));
 
     auto excludeEmailRegularExpressionLayout = new QHBoxLayout;
     excludeEmailRegularExpressionLayout->setContentsMargins({});
     mainLayout->addLayout(excludeEmailRegularExpressionLayout);
 
-    auto excludeEmailRegularExpressionLabel = new QLabel(i18n("Exclude email with Regular Expression:"), this);
+    auto excludeEmailRegularExpressionLabel = new QLabel(i18nc("@label:textbox", "Exclude email with Regular Expression:"), this);
     excludeEmailRegularExpressionLabel->setObjectName("email_regularexpression_label"_L1);
     excludeEmailRegularExpressionLayout->addWidget(excludeEmailRegularExpressionLabel);
 
@@ -137,7 +137,7 @@ BlackListBalooEmailCompletionWidget::BlackListBalooEmailCompletionWidget(QWidget
     mExcludeEmailFromRegularExpressionLineEdit->setObjectName("exclude_email_lineedit"_L1);
     mExcludeEmailFromRegularExpressionLineEdit->setClearButtonEnabled(true);
     KLineEditEventHandler::catchReturnKey(mExcludeEmailFromRegularExpressionLineEdit);
-    mExcludeEmailFromRegularExpressionLineEdit->setPlaceholderText(i18n("Separate regular expression with \'%1\'", QLatin1Char(',')));
+    mExcludeEmailFromRegularExpressionLineEdit->setPlaceholderText(i18nc("@info:placeholder", "Separate regular expression with \'%1\'", QLatin1Char(',')));
 
     connect(mEmailList, &QListWidget::itemSelectionChanged, this, &BlackListBalooEmailCompletionWidget::slotSelectionChanged);
     slotSelectionChanged();
