@@ -11,7 +11,7 @@
 #include "pimcommonakonadi_export.h"
 #include <QDialog>
 
-namespace KLDAP
+namespace KLDAPCore
 {
 class LdapClientSearch;
 }
@@ -27,16 +27,13 @@ class PIMCOMMONAKONADI_EXPORT CompletionOrderEditor : public QDialog
     Q_OBJECT
 
 public:
-    explicit CompletionOrderEditor(KLDAP::LdapClientSearch *ldapSearch, QWidget *parent = nullptr);
+    explicit CompletionOrderEditor(KLDAPCore::LdapClientSearch *ldapSearch, QWidget *parent = nullptr);
     ~CompletionOrderEditor() override;
 
-private Q_SLOTS:
-    void slotOk();
-
 private:
-    void readConfig();
-    void writeConfig();
+    PIMCOMMONAKONADI_NO_EXPORT void slotOk();
+    PIMCOMMONAKONADI_NO_EXPORT void readConfig();
+    PIMCOMMONAKONADI_NO_EXPORT void writeConfig();
     std::unique_ptr<CompletionOrderEditorPrivate> const d;
 };
 } // namespace
-
