@@ -9,12 +9,12 @@
 using namespace Qt::Literals::StringLiterals;
 
 #include <KDescendantsProxyModel>
-#include <KLDAPWidgets/LdapClient>
-#include <KLDAPWidgets/LdapClientSearch>
+#include <KLDAPCore/LdapClient>
+#include <KLDAPCore/LdapClientSearch>
 
 #include <KContacts/Addressee>
 #include <KContacts/ContactGroup>
-#include <KLDAPWidgets/LdapClientSearchConfig>
+#include <KLDAPCore/LdapClientSearchConfig>
 
 #include <Akonadi/ChangeRecorder>
 #include <Akonadi/CollectionFilterProxyModel>
@@ -43,7 +43,7 @@ CompletionOrderEditorAdaptor::CompletionOrderEditorAdaptor(QObject *parent)
 class LDAPCompletionItem : public CompletionItem
 {
 public:
-    explicit LDAPCompletionItem(KLDAPWidgets::LdapClient *ldapClient)
+    explicit LDAPCompletionItem(KLDAPCore::LdapClient *ldapClient)
         : mLdapClient(ldapClient)
     {
         mWeight = mLdapClient->completionWeight();
@@ -66,7 +66,7 @@ public:
 
     void save(CompletionOrderWidget *) override
     {
-        KConfig *config = KLDAPWidgets::LdapClientSearchConfig::config();
+        KConfig *config = KLDAPCore::LdapClientSearchConfig::config();
         KConfigGroup group(config, QStringLiteral("LDAP"));
         group.writeEntry(QStringLiteral("SelectedCompletionWeight%1").arg(mLdapClient->clientNumber()), mWeight);
         group.sync();
@@ -94,7 +94,7 @@ protected:
     }
 
 private:
-    KLDAPWidgets::LdapClient *mLdapClient = nullptr;
+    KLDAPCore::LdapClient *mLdapClient = nullptr;
     int mWeight;
 };
 
@@ -257,7 +257,7 @@ CompletionOrderWidget::CompletionOrderWidget(QWidget *parent)
     mUpButton->setObjectName("mUpButton"_L1);
     mUpButton->setIcon(QIcon::fromTheme(QStringLiteral("go-up")));
     mUpButton->setEnabled(false); // b/c no item is selected yet
-    mUpButton->setToolTip(i18n("Move Up"));
+    mUpButton->setToolTip(i18nc("@info:tooltip", "Move Up"));
     mUpButton->setFocusPolicy(Qt::StrongFocus);
 
     mDownButton = new QPushButton(upDownBox);
@@ -266,7 +266,7 @@ CompletionOrderWidget::CompletionOrderWidget(QWidget *parent)
     mDownButton->setObjectName("mDownButton"_L1);
     mDownButton->setIcon(QIcon::fromTheme(QStringLiteral("go-down")));
     mDownButton->setEnabled(false); // b/c no item is selected yet
-    mDownButton->setToolTip(i18n("Move Down"));
+    mDownButton->setToolTip(i18nc("@info:tooltip", "Move Down"));
     mDownButton->setFocusPolicy(Qt::StrongFocus);
 
     auto spacer = new QWidget(upDownBox);
@@ -331,8 +331,8 @@ void CompletionOrderWidget::loadCompletionItems()
 {
     if (mLdapSearch) {
         // The first step is to gather all the data, creating CompletionItem objects
-        const QList<KLDAPWidgets::LdapClient *> listClients = mLdapSearch->clients();
-        for (KLDAPWidgets::LdapClient *client : listClients) {
+        const QList<KLDAPCore::LdapClient *> listClients = mLdapSearch->clients();
+        for (KLDAPCore::LdapClient *client : listClients) {
             new CompletionViewItem(mListView, new LDAPCompletionItem(client));
         }
     }
@@ -368,7 +368,7 @@ void CompletionOrderWidget::loadCompletionItems()
     mDirty = false;
 }
 
-void CompletionOrderWidget::setLdapClientSearch(KLDAPWidgets::LdapClientSearch *ldapSearch)
+void CompletionOrderWidget::setLdapClientSearch(KLDAPCore::LdapClientSearch *ldapSearch)
 {
     mLdapSearch = ldapSearch;
 }
